@@ -42,7 +42,7 @@ describe 'tempest' do
       end
 
       it 'uses a resource to configure image_ref from image_name' do
-        is_expected.to contain_tempest_glance_id_setter('image_ref').with_image_name('cirros')
+        is_expected.to contain_tempest_glance_id_setter('compute/image_ref').with_image_name('cirros')
       end
     end
 
@@ -77,7 +77,7 @@ describe 'tempest' do
       end
 
       it 'uses a resource to configure public_network_id from public_network_name' do
-        is_expected.to contain_tempest_neutron_net_id_setter('public_network_id').with_network_name('public')
+        is_expected.to contain_tempest_neutron_net_id_setter('network/public_network_id').with_network_name('public')
       end
     end
 
@@ -184,7 +184,7 @@ describe 'tempest' do
 
           is_expected.to contain_vcsrepo('/var/lib/tempest').with(
             :ensure   => 'present',
-            :source   => 'git://github.com/openstack/tempest.git',
+            :source   => 'https://opendev.org/openstack/tempest',
             :revision => nil,
             :provider => 'git',
             :require  => 'Package[git]',
@@ -244,7 +244,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
           is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => nil)
-          is_expected.to contain_tempest_config('database/db_flavor_ref').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('database/db_flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('service_available/cinder').with(:value => true)
           is_expected.to contain_tempest_config('volume-feature-enabled/backup').with(:value => false)
           is_expected.to contain_tempest_config('service_available/glance').with(:value => true)
@@ -300,13 +300,13 @@ describe 'tempest' do
         end
 
         it 'set glance id' do
-          is_expected.to contain_tempest_glance_id_setter('image_ref').with(
+          is_expected.to contain_tempest_glance_id_setter('compute/image_ref').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name',
           )
 
-          is_expected.to contain_tempest_glance_id_setter('image_ref_alt').with(
+          is_expected.to contain_tempest_glance_id_setter('compute/image_ref_alt').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name alt',
@@ -314,7 +314,7 @@ describe 'tempest' do
         end
 
         it 'neutron net id' do
-          is_expected.to contain_tempest_neutron_net_id_setter('public_network_id').with(
+          is_expected.to contain_tempest_neutron_net_id_setter('network/public_network_id').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :network_name      => 'network name',
@@ -394,17 +394,17 @@ describe 'tempest' do
       end
 
       it "sets flavor id using setter" do
-        is_expected.to contain_tempest_flavor_id_setter('flavor_ref').with(
+        is_expected.to contain_tempest_flavor_id_setter('compute/flavor_ref').with(
           :ensure            => 'present',
           :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
           :flavor_name       => 'm1.tiny',
         )
-        is_expected.to contain_tempest_flavor_id_setter('flavor_ref_alt').with(
+        is_expected.to contain_tempest_flavor_id_setter('compute/flavor_ref_alt').with(
           :ensure            => 'present',
           :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
           :flavor_name       => 'm1.nano',
         )
-        is_expected.to contain_tempest_flavor_id_setter('db_flavor_ref').with(
+        is_expected.to contain_tempest_flavor_id_setter('database/db_flavor_ref').with(
           :ensure            => 'present',
           :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
           :flavor_name       => 'm1.micro',
@@ -419,50 +419,45 @@ describe 'tempest' do
        include neutron"
     end
 
-    context 'with when managing tests packages for keystone (required service)' do
-      let :params do
-        { :manage_tests_packages => true }
-      end
-
-      describe "should install keystone tests package" do
-        it { expect { is_expected.to contain_package('python-keystone-tests') } }
-        it { expect { is_expected.to_not contain_package('python-aodh-tests') } }
-      end
+    let :params do
+      { :configure_images      => false,
+        :manage_tests_packages => true }
     end
 
-    context 'with when managing tests packages for aodh (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :aodh_available        => true }
-      end
-
-      describe "should install aodh tests package" do
-        it { expect { is_expected.to contain_package('python-aodh-tests') } }
+    context 'with when managing tests packages for keystone (required service)' do
+      it "should install keystone tests package" do
+        is_expected.to contain_package('python-keystone-tests')
+        is_expected.to_not contain_package('python-sahara-tests-tempest')
       end
     end
 
     context 'with when managing tests packages for sahara (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :sahara_available      => true }
+      before :each do
+        params.merge!({ :sahara_available => true })
       end
 
-      describe "should install sahara tests package" do
-        it { expect { is_expected.to contain_package('python-sahara-tests-tempest') } }
+      it "should install sahara tests package" do
+        if platform_params[:python_sahara_tests]
+          is_expected.to contain_package('python-sahara-tests-tempest')
+        end
       end
     end
 
     context 'with when managing tests packages for neutron (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :neutron_available     => true }
+      before :each do
+        params.merge!({
+          :neutron_available => true,
+          :public_network_id => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        })
       end
 
-      describe "should install neutron and *aas tests packages" do
-        it { expect { is_expected.to contain_package('python-neutron-tests') } }
-        it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
-        it { expect { is_expected.to contain_package('python-neutron-dynamic-routing-tests') } }
-        it { expect { is_expected.to contain_package('python-networking-l2gw-tests-tempest') } }
+      it "should install neutron and *aas tests packages" do
+        if platform_params[:python_neutron_tests]
+          is_expected.to contain_package('python-neutron-tests')
+        end
+        is_expected.to_not contain_package('python-neutron-vpnaas-tests')
+        is_expected.to_not contain_package('python-neutron-dynamic-routing-tests')
+        is_expected.to_not contain_package('python-networking-l2gw-tests-tempest')
       end
     end
   end
@@ -479,32 +474,40 @@ describe 'tempest' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :dev_packages => ['python3-dev',
-                              'libxslt1-dev',
-                              'libxml2-dev',
-                              'libssl-dev',
-                              'libffi-dev',
-                              'patch',
-                              'gcc',
-                              'python3-virtualenv',
-                              'python3-pip' ],
-            :package_name => 'tempest',
-            :pip_command  => 'pip3' }
+          { :dev_packages          => ['python3-dev',
+                                       'libxslt1-dev',
+                                       'libxml2-dev',
+                                       'libssl-dev',
+                                       'libffi-dev',
+                                       'patch',
+                                       'gcc',
+                                       'python3-virtualenv',
+                                       'python3-pip' ],
+            :package_name          => 'tempest',
+            :pip_command           => 'pip3',
+            :python_keystone_tests => 'keystone-tempest-plugin',
+            :python_neutron_tests  => 'neutron-tempest-plugin',
+            :python_sahara_tests   => false }
         when 'RedHat'
-          { :dev_packages => ['python3-devel',
-                              'libxslt-devel',
-                              'libxml2-devel',
-                              'openssl-devel',
-                              'libffi-devel',
-                              'patch',
-                              'gcc'],
-            :package_name => 'openstack-tempest',
-            :pip_command  => 'pip3' }
+          { :dev_packages          => ['python3-devel',
+                                       'libxslt-devel',
+                                       'libxml2-devel',
+                                       'openssl-devel',
+                                       'libffi-devel',
+                                       'patch',
+                                       'gcc'],
+            :package_name          => 'openstack-tempest',
+            :pip_command           => 'pip3',
+            :python_keystone_tests => 'python3-keystone-tests-tempest',
+            :python_neutron_tests  => 'python3-neutron-tests-tempest',
+            :python_sahara_tests   => 'python3-sahara-tests-tempest' }
         end
       end
 
       it_behaves_like 'tempest'
-      it_behaves_like 'tempest with plugins packages'
+      if facts[:operatingsystem] != 'Ubuntu'
+        it_behaves_like 'tempest with plugins packages'
+      end
     end
   end
 end
